# plate-model-manager

![build workflow](https://github.com/michaelchin/plate-model-manager/actions/workflows/build.yml/badge.svg)

This is a dataset manager for plate tectonic models. It is similar to NPM or Conda for software packages.
